import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

from typeguard import check_type

import aws_cdk.aws_iam._jsii
import aws_cdk.aws_s3_assets._jsii
import aws_cdk.aws_sns._jsii
import aws_cdk.core._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "@aws-cdk/aws-servicecatalog",
    "1.167.0",
    __name__[0:-6],
    "aws-servicecatalog@1.167.0.jsii.tgz",
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
